package de.fraunhofer.iem.dataprovider.sarif

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable


@Serializable
data class Sarif(
    @SerialName("runs")
    val runs: List<Run>
)

@Serializable
data class Location(
    @SerialName("physicalLocation")
    val physicalLocation: PhysicalLocation
)

@Serializable
data class Message(
    @SerialName("text")
    val text: String
)

@Serializable
data class PhysicalLocation(
    @SerialName("artifactLocation")
    val artifactLocation: ArtifactLocation,
    @SerialName("region")
    val region: Region
)

@Serializable
data class Region(
    @SerialName("endColumn")
    val endColumn: Int,
    @SerialName("endLine")
    val endLine: Int,
    @SerialName("startColumn")
    val startColumn: Int,
    @SerialName("startLine")
    val startLine: Int
)

@Serializable
data class Result(
    @SerialName("level")
    val level: String,
    @SerialName("locations")
    val locations: List<Location>,
    @SerialName("message")
    val message: Message,
    @SerialName("ruleId")
    val ruleId: String
)

@Serializable
data class Rule(
    @SerialName("helpUri")
    val helpUri: String,
    @SerialName("id")
    val id: String,
    @SerialName("name")
    val name: String,
    @SerialName("shortDescription")
    val shortDescription: ShortDescription
)

@Serializable
data class Run(
    @SerialName("results")
    val results: List<Result>,
    @SerialName("tool")
    val tool: Tool
)

@Serializable
data class ShortDescription(
    @SerialName("text")
    val text: String
)

@Serializable
data class Tool(
    @SerialName("driver")
    val driver: Driver
)

@Serializable
data class Driver(
    @SerialName("downloadUri")
    val downloadUri: String? = null,
    @SerialName("fullName")
    val fullName: String? = null,
    @SerialName("guid")
    val guid: String? = null,
    @SerialName("informationUri")
    val informationUri: String? = null,
    @SerialName("language")
    val language: String? = null,
    @SerialName("name")
    val name: String? = null,
    @SerialName("organization")
    val organization: String? = null,
    @SerialName("rules")
    val rules: List<Rule>,
    @SerialName("semanticVersion")
    val semanticVersion: String? = null,
    @SerialName("version")
    val version: String? = null
)

@Serializable
data class ArtifactLocation(
    @SerialName("uri")
    val uri: String
)
