package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.gitlab.Platform
import de.fraunhofer.iem.dataprovider.gitlab.Repository
import de.fraunhofer.iem.dataprovider.taskManager.Event
import de.fraunhofer.iem.dataprovider.taskManager.GitCloneDone
import org.eclipse.jgit.api.Git
import java.nio.file.Paths
import java.util.*


data class GitRepository(val name: String, val uri: String, val id: Long, val platform: Platform)

fun GitRepository.toDbObject(): Repository {
    val repo = Repository()
    repo.name = this.name
    repo.repoId = this.id
    repo.platform = this.platform
    return repo
}

class CloneGitTask(
    private val gitRepository: GitRepository,
    private val repoDbId: UUID,
    override val responseChannel: suspend (task: Event) -> Unit,
    private val outputPath: String,
) : Task() {

    override suspend fun execute() {

        val outputDirName = "${gitRepository.name}-${taskID}"
        val outputDirectory = Paths.get(outputPath, outputDirName)
        logger.info("Cloning ${gitRepository.name} into $outputDirectory")

        val git: Git = Git.cloneRepository()
            .setURI(gitRepository.uri)
            .setDirectory(outputDirectory.toFile())
            .call()
        git.close()

        responseChannel(GitCloneDone(taskID, repoDbId, outputDirectory.toString()))

        logger.info("Finished cloning ${gitRepository.name}")
    }
}